```
█▀▀ █ ▀█▀ █▀▄ █░█ █▀▄▀█ █▀█  version
█▄█ █ ░█░ █▄▀ █▄█ █░▀░█ █▀▀  1.0.1  
```


# Usage

```
usage: gd [-h] [-u USERNAME] [-l LOCATION]

Dump all repos of a github account at once.

optional arguments:
  -h, --help            show this help message and exit
  -u USERNAME, --username USERNAME
                        username of the github account
  -l LOCATION, --location LOCATION
                        location to save dumped repos
```